import { __decorate, __param } from "tslib";
import { Container } from '@microsoft/fast-foundation';
import { RouterConfiguration } from '@microsoft/fast-router';
import { defaultLayout } from '../layouts';
import { Account } from './account/account';
import { Appearance } from './appearance/appearance';
import { NotFound } from './not-found/not-found';
import { Notifications } from './notifications/notifications';
let MainRouterConfig = class MainRouterConfig extends RouterConfiguration {
    constructor(container) {
        super();
        this.container = container;
    }
    configure() {
        this.title = 'Settings';
        this.defaultLayout = defaultLayout;
        this.routes.map({ path: '', redirect: 'account' }, {
            path: 'account',
            element: Account,
            title: 'Account',
            name: 'account',
            settings: { foo: 'bar' },
        }, { path: 'appearance', element: Appearance, title: 'Appearance', name: 'appearance' }, {
            path: 'notifications',
            element: Notifications,
            title: 'Notifications',
            name: 'notifications',
        }, { path: 'not-found', element: NotFound, title: 'Not Found', name: 'not-found' });
        this.routes.fallback(() => ({ redirect: 'not-found' }));
        this.contributors.push({
            navigate: (phase) => {
                const settings = phase.route.settings;
                if (settings && settings.public) {
                    return;
                }
            },
        });
    }
    construct(Type) {
        return this.container.get(Type);
    }
};
MainRouterConfig = __decorate([
    __param(0, Container)
], MainRouterConfig);
export { MainRouterConfig };
